fn forbidden(message: &str) -> ControllerErrorExpand description
Builds the 403 forbidden error the langs client expects for a token missing the scope.
fn forbidden(message: &str) -> ControllerErrorBuilds the 403 forbidden error the langs client expects for a token missing the scope.